# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.system.help import GmpHelpTestMixin
from ...gmpv226 import GMPTestCase


class GMPHelpTestCase(GmpHelpTestMixin, GMPTestCase):
    pass
