# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
Package for supported Greenbone HTTP APIs.

Currently only `openvasd version 1 <https://greenbone.github.io/scanner-api/#/>`_ is supported.
"""
