# SPDX-FileCopyrightText: 2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

from ._entity_id import EntityID
from ._version import Version

__all__ = (
    "EntityID",
    "Version",
)
