# SPDX-FileCopyrightText: 2025 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later

"""
GMP Request implementations for GMP version 22.7.
"""

from gvm.protocols.gmp.requests.v227._scanners import Scanners, ScannerType

from .._entity_id import EntityID
from .._version import Version
from ..v226 import (
    Aggregates,
    AggregateStatistic,
    AlertCondition,
    AlertEvent,
    AlertMethod,
    Alerts,
    AliveTest,
    AuditReports,
    Audits,
    Authentication,
    CertBundAdvisories,
    Cpes,
    CredentialFormat,
    Credentials,
    CredentialType,
    Cves,
    DfnCertAdvisories,
    EntityType,
    Feed,
    FeedType,
    Filters,
    FilterType,
    Groups,
    Help,
    HelpFormat,
    Hosts,
    HostsOrdering,
    InfoType,
    Notes,
    Nvts,
    OperatingSystems,
    Overrides,
    Permissions,
    PermissionSubjectType,
    Policies,
    PortLists,
    PortRangeType,
    ReportConfigParameter,
    ReportConfigs,
    ReportFormats,
    ReportFormatType,
    Reports,
    ResourceNames,
    ResourceType,
    Results,
    Roles,
    ScanConfigs,
    Schedules,
    SecInfo,
    Severity,
    SnmpAuthAlgorithm,
    SnmpPrivacyAlgorithm,
    SortOrder,
    SystemReports,
    Tags,
    Targets,
    Tasks,
    Tickets,
    TicketStatus,
    TLSCertificates,
    TrashCan,
    UserAuthType,
    Users,
    UserSettings,
    Vulnerabilities,
)

__all__ = (
    "AggregateStatistic",
    "Aggregates",
    "AlertCondition",
    "AlertEvent",
    "AlertMethod",
    "Alerts",
    "AliveTest",
    "AuditReports",
    "Audits",
    "Authentication",
    "CertBundAdvisories",
    "Cpes",
    "CredentialFormat",
    "CredentialType",
    "Credentials",
    "Cves",
    "DfnCertAdvisories",
    "EntityID",
    "EntityType",
    "Feed",
    "FeedType",
    "FilterType",
    "Filters",
    "Groups",
    "Help",
    "HelpFormat",
    "Hosts",
    "HostsOrdering",
    "InfoType",
    "Notes",
    "Nvts",
    "OperatingSystems",
    "Overrides",
    "PermissionSubjectType",
    "Permissions",
    "Policies",
    "PortLists",
    "PortRangeType",
    "ReportConfigParameter",
    "ReportConfigs",
    "ReportFormatType",
    "ReportFormats",
    "Reports",
    "ResourceNames",
    "ResourceType",
    "Results",
    "Roles",
    "ScanConfigs",
    "ScannerType",
    "Scanners",
    "Schedules",
    "SecInfo",
    "Severity",
    "SnmpAuthAlgorithm",
    "SnmpPrivacyAlgorithm",
    "SortOrder",
    "SystemReports",
    "TLSCertificates",
    "Tags",
    "Targets",
    "Tasks",
    "TicketStatus",
    "Tickets",
    "TrashCan",
    "UserAuthType",
    "UserSettings",
    "Users",
    "Version",
    "Vulnerabilities",
)
