# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_get_vulnerabilities import GmpGetVulnerabilitiesTestMixin
from .test_get_vulnerability import GmpGetVulnerabilityTestMixin

__all__ = ("GmpGetVulnerabilitiesTestMixin", "GmpGetVulnerabilityTestMixin")
