# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_get_result import GmpGetResultTestMixin
from .test_get_results import GmpGetResultsTestMixin

__all__ = (
    "GmpGetResultTestMixin",
    "GmpGetResultsTestMixin",
)
