# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_get_protocol_version import GmpGetProtocolVersionTestCase
from .test_get_version import GmpGetVersionTestCase

__all__ = ("GmpGetProtocolVersionTestCase", "GmpGetVersionTestCase")
