# SPDX-FileCopyrightText: 2021-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_get_feed import GmpGetFeedTestMixin
from .test_get_feeds import GmpGetFeedsTestMixin

__all__ = ("GmpGetFeedTestMixin", "GmpGetFeedsTestMixin")
