# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from .test_get_resource_name import GmpGetResourceNameTestMixin
from .test_get_resource_names_list import GmpGetResourceNamesListTestMixin

__all__ = ("GmpGetResourceNameTestMixin", "GmpGetResourceNamesListTestMixin")
