# SPDX-FileCopyrightText: 2018-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#
"""
Package for supported Greenbone Protocol versions.

Currently GMP version 22.4, `GMP version 22.5`_,
`GMP version 22.6`_, `GMP version 22.7`_
and `OSP version 1`_ are supported.

.. _GMP version 22.5:
    https://docs.greenbone.net/API/GMP/gmp-22.5.html
.. _GMP version 22.6:
    https://docs.greenbone.net/API/GMP/gmp-22.6.html
.. _GMP version 22.7:
    https://docs.greenbone.net/API/GMP/gmp-22.7.html
.. _OSP version 1:
    https://docs.greenbone.net/API/OSP/osp-1.2.html
"""
