# SPDX-FileCopyrightText: 2023-2024 Greenbone AG
#
# SPDX-License-Identifier: GPL-3.0-or-later
#

from ...gmpv224.system.system_reports import GmpGetSystemReportsTestMixin
from ...gmpv226 import GMPTestCase


class GMPGetSystemReportsTestCase(GmpGetSystemReportsTestMixin, GMPTestCase):
    pass
